@@ -24,7 +24,7 @@ FOLDER: str = join(ROOT, "logs")
 
 BACKUP: dict = {
     "LOGGER": {
-        "basename": "logpie",  # if handler is `file`
+        # "basename": "logpie",  # if handler is `file`
         "handler": "console",  # or `file` or `nostream` (does nothing)
         "debug": False,  # if set to `True` it will also print `DEBUG` messages
     }
